/* Ritorna true solo se è passato almeno il tempo di un fotogramma, così, se
 * l'esecuzione è stata molto veloce, evita di ridisegnare inutilmente lo schermo
 * Nel frattempo inserisce un leggero SDL_Delay() per evitare di fondere la CPU
 * Il gioco potrebbe venire rallentato se il processore è troppo lento, ma si
 * evita almeno che diventi ingiocabile su processori troppo veloci */
bool fps()
{
  /* periodo = 1/maxfps (indicare in millisecondi) */
  unsigned int ritardo = SDL_GetTicks() - lastframe + 1;
  if (ritardo < opzione.maxfps) { SDL_Delay(1); return false; }
  lastframe = SDL_GetTicks();
  return true;
}

/* Disegna tutti gli elementi grafici dello schermo */
bool grafica()
{
  static unsigned long LastTicks, fpscolor;

  boxColor(schermo, 1, 1, 852, 478, 0x000000FF); /* Cancella tutta l'area di gioco */

  for (short y = 0; y < height; y++)
    for (short x = 0; x < width; x++)
    {
      block[x][y].grafica(x, y);
    }

  rectangleColor(schermo, 0, 0, 639, 479, 0x008800FF); /* Bordi dello schermo di gioco*/

  /* Giocatore */
  if (player.sparaspara) filledCircleColor(schermo, player.x, 460, 6, 0xFF0000FF);
  roundedBoxColor(schermo, player.x - player.lung, 460, player.x + player.lung, 470, 1, 0xC8C8C8FF);

  for (short n = 0; n < n_balls; n++)
  { palla[n].grafica(); }

  for (short n = 0; n < n_bonus; n++)
  { bonus[n].grafica(); }

  if (! opzione.panscan)
  {
    font(702, 5, "Livello", 0xFFFFFF);
    font(774, 5, itoa(lvl), 0xFFFFFF);
    font(747 - (((strlen(title)) >> 1) * FONTW), 25, title, 0xAA0000);
    font(725, 65, "Punti", 0xFFFFFF);
    char tmp[12]; strcpy(tmp, itoa(player.punti));
    font((747 - (strlen(tmp) >> 1) * FONTW), 85, tmp, 0xFFFFFF);
    font(729, 125, "Vite", 0xFFFFFF);
    strcpy(tmp, itoa(player.vite));
    font(747 - (strlen(tmp) * FONTW / 2), 145, tmp, 0xFFFFFF);
    font(729, 185, itoa(gameinfo.cfps), fpscolor);
    font(756, 185, "fps", 0xFFFFFF);
  }
  else
  {
    font(10, 5, "Vite:", 0xFFFFFF);
    font(58, 5, itoa(player.vite), 0xFFFFFF);
    font(140, 5, "Punti:", 0xFFFFFF);
    font(196, 5, itoa(player.punti), 0xFFFFFF);
    font(300, 5, itoa(lvl), 0xFFFFFF);
    font(320, 5, title, 0xC80000);
    font(585, 5, itoa(gameinfo.cfps), fpscolor);
    font(612, 5, "fps", 0xFFFFFF);
  }

  #define LOW_FPS 0xFF0000
  #define NORMAL_FPS 0xFFFF00
  #define HIGH_FPS 0x00FF00

  gameinfo.fpscount++;
  if (gameinfo.fpscount >= 10)
  {
    gameinfo.cfps = 10 / ((double)(SDL_GetTicks() - LastTicks) / (double)(1000));
    if (gameinfo.cfps < 15) { fpscolor = LOW_FPS; clog << "[W] Low fps! Check minimum requirements and/or change screen settings\n"; }
      else if (gameinfo.cfps > 29) fpscolor = HIGH_FPS;
        else fpscolor = NORMAL_FPS;
    LastTicks = SDL_GetTicks();
    gameinfo.fpscount = 0;
  }

  SDL_Flip(schermo);
  return true;
}
